@@ -33,10 +33,12 @@ logger.name = __name__
 
 
 __all__ = ["Colors", "InputOptions", "SnakemakeOptions", "SlurmOptions",
-    "PipelineManager", "GeneralOptions", "print_version", "CutadaptOptions",
+    "SequanaManager", "PipelineManager", "GeneralOptions", "print_version", "CutadaptOptions",
     "KrakenOptions", "init_pipeline", "sequana_epilog", "sequana_prolog"]
 
 
+deprecated = "This is a deprecated class {}. Please use sequana_pipetools instead of sequana.pipeline_common."
+
 class Colors:
     """
 
@@ -103,7 +105,7 @@ def guess_scheduler():
 
 class GeneralOptions():
     def __init__(self):
-        pass
+        print(deprecated.format("GeneralOptions"))
 
     def add_options(self, parser):
         parser.add_argument(
@@ -125,6 +127,7 @@ class GeneralOptions():
         parser.add_argument("--deps", action="store_true",
             help="Show the known dependencies of the pipeline")
         parser.add_argument("--level", dest="level", default="INFO",
+            choices=['INFO', 'DEBUG', 'WARNING', 'ERROR', 'CRITICAL'],
             help="logging level in INFO, DEBUG, WARNING, ERROR, CRITICAL")
 
 
@@ -138,6 +141,7 @@ class InputOptions():
         If so, the add_input_readtag must be set
         """
         self.group_name = group_name
+        print(deprecated.format("InputOptions"))
         self.input_directory = input_directory
         self.input_pattern = input_pattern
         self.add_is_paired = add_is_paired
@@ -182,6 +186,7 @@ class InputOptions():
 
 class KrakenOptions():
     def __init__(self, group_name="section_kraken"):
+        print(deprecated.format("KrakenOptions"))
         self.group_name = group_name
 
     def add_options(self, parser):
@@ -227,6 +232,7 @@ class CutadaptOptions():
 
     def __init__(self, group_name="section_cutadapt"):
         self.group_name = group_name
+        print(deprecated.format("CutadaptOptions"))
 
     def add_options(self, parser):
 
@@ -348,6 +354,7 @@ class SnakemakeOptions():
     def __init__(self, group_name="snakemake", working_directory="analysis"):
         self.group_name = group_name
         self.workdir = working_directory
+        print(deprecated.format("SnakemakeOptions"))
 
     def _default_jobs(self):
         if guess_scheduler() == "slurm":
@@ -386,15 +393,19 @@ class SnakemakeOptions():
 class SlurmOptions():
     def __init__(self, group_name="slurm", memory=4000, queue="common", cores=4):
         """
-        class Options(argparse.ArgumentParser, SlurmOptions):
-            def __init__(self, prog"whatever")
-                super(Options, self).__init__(usage="todo",
-                    prog="whatever",description=""
-                self.add_argument(...)
-                ...
-                self.add_slurm_options()
+
+        ::
+
+            class Options(argparse.ArgumentParser, SlurmOptions):
+                def __init__(self, prog="whatever")
+                    super(Options, self).__init__(usage="todo",
+                        prog="whatever",description=""
+                    self.add_argument(...)
+                    ...
+                    self.add_slurm_options()
 
         """
+        print(deprecated.format("SlurmOptions"))
         self.group_name = group_name
         self.memory = memory
         self.cores = cores
@@ -432,7 +443,7 @@ def init_pipeline(NAME):
     This is called even before parsing options
     """
     import sys
-
+    print("deprecated use the before_pipeline from sequana_pipetools")
     if "--version" in sys.argv:
         print_version(NAME)
         sys.exit(0)
@@ -494,11 +505,12 @@ def get_pipeline_location(pipeline_name):
     options = Opt()
     options.workdir = "."
     options.version = False
-    p = PipelineManager(options, pipeline_name)
+    p = SequanaManager(options, pipeline_name)
     return p._get_package_location()
 
 
-class PipelineManager():
+
+class SequanaManager():
     """
 
     """
@@ -539,10 +551,27 @@ class PipelineManager():
         self.module = Module(self.name)
         if self.module.is_pipeline() is False:
             raise ValueError("{} does not seem to be installed or is not a valid pipeline".format(self.name))
+        self.module.is_executable()
 
         # If this is a pipeline, let us load its config file
-        self.config = SequanaConfig(self.module.config)
+        # Do we start from an existing project with a valid config file ?
+        if "from_project" in dir(options) and options.from_project:
+            cfg_project_filename = None
+            if os.path.exists(options.from_project) and options.from_project.endswith("config.yaml"):
+                cfg_project_filename = options.from_project
+            elif ".sequana" in options.from_project:
+                if os.path.exists(options.from_project + "/config.yaml"):
+                    cfg_project_filename = options.from_project
+            elif os.path.exists(options.from_project + "/.sequana/config.yaml"):
+                cfg_project_filename = options.from_project + "/.sequana/config.yaml"
 
+            if cfg_project_filename is None:
+                raise IOError("Could not find config.yaml in the project specified {}".format(
+                    options.from_project))
+            logger.info("Reading existing config file {}".format(cfg_project_filename))
+            self.config = SequanaConfig(cfg_project_filename)
+        else:
+            self.config = SequanaConfig(self.module.config)
 
         # the working directory
         self.workdir = options.workdir
@@ -627,13 +656,14 @@ class PipelineManager():
         """
         # First we create the beginning of the command with the optional
         # parameters for a run on a SLURM scheduler
+        logger.info("Welcome to Sequana pipelines suite (sequana.readthedocs.io)")
 
-        cmd = "#!/bin/bash\nsnakemake -s {}.rules"
+        cmd = "#!/bin/bash\nsnakemake -s {}.rules --stats stats.txt"
         self.command = cmd.format(self.name)
 
         # FIXME a job is not a core. Ideally, we should add a core option
         if self._guess_scheduler() == "local":
-            self.command += " -p --cores {}".format(self.options.jobs)
+            self.command += " -p --cores {} ".format(self.options.jobs)
         else:
             self.command += " -p --jobs {}".format(self.options.jobs)
 
@@ -661,7 +691,16 @@ class PipelineManager():
                     self.options.slurm_cores_per_job,
                     slurm_queue)
 
+        # This should be in the setup, not in the teardown since we may want to
+        # copy files when creating the pipeline. This is the case e.g. in the
+        # rnaseq pipeline. It is a bit annoying since if there is failure
+        # between setup and teardown, the directories are created but no way to
+        # fix that.
+        self._create_directories()
+
+    def _create_directories(self):
         # Now we create the directory to store the config/pipeline
+
         if os.path.exists(self.workdir) is True and self.options.force is False:
             print(self.colors.failed(
             "Output path {} exists already. Use --force".format(self.workdir)))
@@ -710,6 +749,7 @@ class PipelineManager():
 to analyse non-fastQ files (e.g. BAM)""")
             sys.exit(1)
 
+
     def teardown(self, check_schema=True, check_input_files=True):
         """Save all files required to run the pipeline and perform sanity checks
 
@@ -739,18 +779,27 @@ to analyse non-fastQ files (e.g. BAM)""")
         if check_input_files:
             self.check_input_files()
 
+
         # the config file
         self.config._update_yaml()
-        self.config.save("{}/config.yaml".format(self.workdir))
         self.config.save("{}/{}/config.yaml".format(self.workdir , ".sequana"))
+        try:
+            os.symlink("{}/config.yaml".format(".sequana"),
+                   "{}/config.yaml".format(self.workdir))
+        except:
+            pass
 
         # the command
         with open("{}/{}.sh".format(self.workdir, self.name), "w") as fout:
             fout.write(self.command)
 
         # the snakefile
-        shutil.copy(self.module.snakefile, "{}".format(self.workdir))
         shutil.copy(self.module.snakefile, "{}/{}".format(self.workdir, ".sequana"))
+        try:
+            os.symlink("{}/{}.rules".format(".sequana", self.name), 
+                "{}/{}.rules".format(self.workdir, self.name))
+        except:
+            pass
 
         # the cluster config if any
         if self.module.logo:
@@ -813,6 +862,35 @@ to analyse non-fastQ files (e.g. BAM)""")
                 subprocess.call(cmd.split(), stdout=fout)
             logger.debug("Saved your pip environement into pip.txt (conda not found)")
 
+        # General information
+        from easydev import CustomConfig
+        configuration = CustomConfig("sequana", verbose=False)
+        sequana_config_path = configuration.user_config_dir
+        completion = sequana_config_path + "/pipelines/{}.sh".format(self.name)
+        if os.path.exists(completion):
+            with open(completion, "r") as fin:
+                line = fin.readline()
+                if line.startswith("#version:"):
+                    version = line.split("#version:")[1].strip()
+                    from distutils.version import StrictVersion
+                    if StrictVersion(version) <  StrictVersion(self._get_package_version()):
+                        msg = (
+                            "The version {} of your completion file for the"
+                            "  {} pipeline seems older than the installed"
+                            " pipeline itself ({}). "
+                            "Please, consider updating the completion file {}"
+                            " using the following command: \n\t sequana_completion --name {}\n"
+                            "available in the sequana_pipetools package (pip "
+                                "install sequana_completion)")
+                        msg = msg.format(version, self.name, 
+                            self._get_package_version(), completion, self.name)
+                        logger.info(msg)
+
+        else:
+            # we could print a message to use the sequana_completion tools
+            # be maybe boring on the long term
+            pass
+
     def update_config(self, config, options, section_name):
         for option_name in config[section_name]:
             try:
@@ -822,3 +900,8 @@ to analyse non-fastQ files (e.g. BAM)""")
                 logger.debug("update_config. Could not find {}".format(option_name))
 
 
+class PipelineManager(SequanaManager):
+    def __init__(self, options, name="undefined"):
+        super(PipelineManager, self).__init__(options, name=name)
+        print(deprecated.format("PipelineManager"))
+        print("Use SequanaManager instead")
