@@ -17,11 +17,11 @@
 
 from sequana.lazy import pylab
 from sequana import logger
-
+from sequana.viz import clusterisation
 __all__ = ['PCA']
 
 
-class PCA():
+class PCA(clusterisation.Cluster):
     """
 
     .. plot::
@@ -41,14 +41,10 @@ class PCA():
 
     """
     def __init__(self, data, colors={}):
+        super(PCA, self).__init__(data, colors)
 
-        self.df = data
-        self.labels = data.columns
-        self.colors = {x:'r' for x in self.labels}
-        for k,v in colors.items():
-            self.colors[k] = v
-
-    def plot_pca_vs_max_features(self, max_features=100, n_components=2):
+    def plot_pca_vs_max_features(self, step=100, n_components=2,
+            progress=True):
         """
 
         .. plot::
@@ -66,13 +62,21 @@ class PCA():
             p.plot_pca_vs_max_features()
 
         """
-        assert n_components in [2,3]
+        assert n_components in [2,3,4]
         N = len(self.df)
-        if max_features > N:
-            max_features = N
+        if step > N:
+            step = N
+
         # We start with at least 5 features
-        X = range(5, N, max_features)
-        Y = [self.plot(n_components=n_components, max_features=x, show_plot=False) for x in X]
+        X = range(10, N, step)
+        from easydev import Progress
+        pb = Progress(len(X))
+        Y = []
+        for i, x in enumerate(X):
+            res = self.plot(n_components=n_components, max_features=x, show_plot=False)
+            Y.append(res)
+            if progress: pb.animate(i+1)
+
         sub = n_components
         pylab.subplot(sub,1,1)
         pylab.plot(X, [y[0]*100 for y in Y])
@@ -80,10 +84,14 @@ class PCA():
         pylab.subplot(sub,1,2)
         pylab.plot(X, [y[1]*100 for y in Y])
         pylab.ylabel("PC2 (%)")
-        if sub == 3:
+        if sub >= 3:
             pylab.subplot(sub,1,3)
             pylab.plot(X, [y[2]*100 for y in Y])
             pylab.ylabel("PC3 (%)")
+        if sub >= 4:
+            pylab.subplot(sub,1,4)
+            pylab.plot(X, [y[3]*100 for y in Y])
+            pylab.ylabel("PC4 (%)")
 
     def plot(self, n_components=2, transform="log", switch_x=False,
             switch_y=False, switch_z=False, colors=None,
@@ -97,36 +105,18 @@ class PCA():
             with zeros, are set to 1
         """
         assert transform in ['log', 'anscombe']
-        
-        from sklearn.preprocessing import StandardScaler
+
         from sklearn.decomposition import PCA
         import numpy as np
 
         pylab.clf()
         pca = PCA(n_components)
 
-        # normalise the data
-        scaler = StandardScaler()
-
-        # First, we transform the data
-        data = self.df.copy()
-        data = data.replace(0, 1)
-        self.data = data
-        if transform == "log":
-            data = pylab.log10(data)
-        elif transform == "anscombe":
-            from sequana.vst import VST
-            data = VST.anscombe(data)
-
-        # then we keep only the first N most dispersed features
-        tokeep = data.std(axis=1).sort_values(ascending=False).index[0:max_features]
-        data = data.loc[tokeep]
-
-        data = scaler.fit_transform(data)
+        data, kept = self.scale_data(transform_method=transform, max_features=max_features)
 
         pca.fit(data.T)
 
-        Xr = pca.transform(scaler.fit_transform(self.df.loc[tokeep].T))
+        Xr = pca.transform(self.scaler.fit_transform(self.df.loc[kept].T))
         self.Xr = Xr
 
         if switch_x:
@@ -139,51 +129,16 @@ class PCA():
         # PC1 vs PC2
         if show_plot:
             pylab.figure(1)
-            self._plot(Xr, pca, 0,1, colors=colors)
+            self._plot(Xr, pca=pca, pc1=0,pc2=1, colors=colors)
 
         if len(pca.explained_variance_ratio_) >= 3:
             if show_plot:
                 pylab.figure(2)
-                self._plot(Xr, pca, 0,2, colors=colors)
+                self._plot(Xr, pca=pca, pc1=0,pc2=2, colors=colors)
                 pylab.figure(3)
-                self._plot(Xr, pca, 1,2, colors=colors)
+                self._plot(Xr, pca=None, pc1=1,pc2=2, colors=colors)
 
         return pca.explained_variance_ratio_
 
-    def _plot(self, Xr, pca, pc1=0, pc2=1, colors=None):
-        if colors is None:
-            colors = [self.colors[k] for k in self.labels]
-            if len(colors) != len(Xr):
-                colors = ["r"] * len(Xr[:,0])
-        else:
-            for k in self.labels:
-                if k not in colors.keys():
-                    logger.warning("No key color for this sample: {}. Set to red".format(k))
-                    colors[k] = "r"
-            colors = [colors[k] for k in self.labels]
-
-        pylab.scatter(Xr[:,pc1], Xr[:,pc2], c=colors)
-        ax = pylab.gca()
-        X1, X2 = pylab.xlim()
-        dX = X2 - X1
-        pylab.xlim([X1 + X1*0.05, X2 + X2*0.05])
-
-        Y1, Y2 = pylab.ylim()
-        dY = Y2 - Y1
-        pylab.ylim([Y1 + Y1*0.05, Y2 + Y2*0.05])
-
-        count = 0
-        for x,y in zip(Xr[:,pc1], Xr[:,pc2]):
-            x += dX / 40
-            y += dY / 40
-            ax.annotate(self.labels[count], (x,y))
-            count += 1
-            if count > 100: 
-                break
-        pylab.xlabel("PC{} ({}%)".format(pc1+1,
-            round(pca.explained_variance_ratio_[pc1]*100, 2)))
-        pylab.ylabel("PC{} ({}%)".format(pc2+1,
-            round(pca.explained_variance_ratio_[pc2]*100, 2)))
-        pylab.grid(True)
 
 
